/**
 * Container Images API
 * API covering the [Registry](/iaas/Content/Registry/Concepts/registryoverview.htm) services.
Use this API to manage resources such as container images and repositories.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { ArtifactsWaiter } from "./artifacts-waiter";
export declare enum ArtifactsApiKeys {
}
export declare class ArtifactsClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": ArtifactsWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new ArtifactsWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): ArtifactsWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): ArtifactsWaiter;
    /**
     * Moves a container repository into a different compartment within the same tenancy. For information about moving
     * resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * @param ChangeContainerRepositoryCompartmentRequest
     * @return ChangeContainerRepositoryCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.19.4/artifacts/ChangeContainerRepositoryCompartment.ts.html |here} to see how to use ChangeContainerRepositoryCompartment API.
     */
    changeContainerRepositoryCompartment(changeContainerRepositoryCompartmentRequest: requests.ChangeContainerRepositoryCompartmentRequest): Promise<responses.ChangeContainerRepositoryCompartmentResponse>;
    /**
     * Upload a signature to an image.
     * @param CreateContainerImageSignatureRequest
     * @return CreateContainerImageSignatureResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.19.4/artifacts/CreateContainerImageSignature.ts.html |here} to see how to use CreateContainerImageSignature API.
     */
    createContainerImageSignature(createContainerImageSignatureRequest: requests.CreateContainerImageSignatureRequest): Promise<responses.CreateContainerImageSignatureResponse>;
    /**
     * Create a new empty container repository. Avoid entering confidential information.
     * @param CreateContainerRepositoryRequest
     * @return CreateContainerRepositoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.19.4/artifacts/CreateContainerRepository.ts.html |here} to see how to use CreateContainerRepository API.
     */
    createContainerRepository(createContainerRepositoryRequest: requests.CreateContainerRepositoryRequest): Promise<responses.CreateContainerRepositoryResponse>;
    /**
     * Delete a container image.
     * @param DeleteContainerImageRequest
     * @return DeleteContainerImageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.19.4/artifacts/DeleteContainerImage.ts.html |here} to see how to use DeleteContainerImage API.
     */
    deleteContainerImage(deleteContainerImageRequest: requests.DeleteContainerImageRequest): Promise<responses.DeleteContainerImageResponse>;
    /**
     * Delete a container image signature.
     * @param DeleteContainerImageSignatureRequest
     * @return DeleteContainerImageSignatureResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.19.4/artifacts/DeleteContainerImageSignature.ts.html |here} to see how to use DeleteContainerImageSignature API.
     */
    deleteContainerImageSignature(deleteContainerImageSignatureRequest: requests.DeleteContainerImageSignatureRequest): Promise<responses.DeleteContainerImageSignatureResponse>;
    /**
     * Delete container repository.
     * @param DeleteContainerRepositoryRequest
     * @return DeleteContainerRepositoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.19.4/artifacts/DeleteContainerRepository.ts.html |here} to see how to use DeleteContainerRepository API.
     */
    deleteContainerRepository(deleteContainerRepositoryRequest: requests.DeleteContainerRepositoryRequest): Promise<responses.DeleteContainerRepositoryResponse>;
    /**
     * Get container configuration.
     * @param GetContainerConfigurationRequest
     * @return GetContainerConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.19.4/artifacts/GetContainerConfiguration.ts.html |here} to see how to use GetContainerConfiguration API.
     */
    getContainerConfiguration(getContainerConfigurationRequest: requests.GetContainerConfigurationRequest): Promise<responses.GetContainerConfigurationResponse>;
    /**
     * Get container image metadata.
     * @param GetContainerImageRequest
     * @return GetContainerImageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.19.4/artifacts/GetContainerImage.ts.html |here} to see how to use GetContainerImage API.
     */
    getContainerImage(getContainerImageRequest: requests.GetContainerImageRequest): Promise<responses.GetContainerImageResponse>;
    /**
     * Get container image signature metadata.
     * @param GetContainerImageSignatureRequest
     * @return GetContainerImageSignatureResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.19.4/artifacts/GetContainerImageSignature.ts.html |here} to see how to use GetContainerImageSignature API.
     */
    getContainerImageSignature(getContainerImageSignatureRequest: requests.GetContainerImageSignatureRequest): Promise<responses.GetContainerImageSignatureResponse>;
    /**
     * Get container repository.
     * @param GetContainerRepositoryRequest
     * @return GetContainerRepositoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.19.4/artifacts/GetContainerRepository.ts.html |here} to see how to use GetContainerRepository API.
     */
    getContainerRepository(getContainerRepositoryRequest: requests.GetContainerRepositoryRequest): Promise<responses.GetContainerRepositoryResponse>;
    /**
     * List container image signatures in an image.
     * @param ListContainerImageSignaturesRequest
     * @return ListContainerImageSignaturesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.19.4/artifacts/ListContainerImageSignatures.ts.html |here} to see how to use ListContainerImageSignatures API.
     */
    listContainerImageSignatures(listContainerImageSignaturesRequest: requests.ListContainerImageSignaturesRequest): Promise<responses.ListContainerImageSignaturesResponse>;
    /**
     * List container images in a compartment.
     * @param ListContainerImagesRequest
     * @return ListContainerImagesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.19.4/artifacts/ListContainerImages.ts.html |here} to see how to use ListContainerImages API.
     */
    listContainerImages(listContainerImagesRequest: requests.ListContainerImagesRequest): Promise<responses.ListContainerImagesResponse>;
    /**
     * List container repositories in a compartment.
     * @param ListContainerRepositoriesRequest
     * @return ListContainerRepositoriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.19.4/artifacts/ListContainerRepositories.ts.html |here} to see how to use ListContainerRepositories API.
     */
    listContainerRepositories(listContainerRepositoriesRequest: requests.ListContainerRepositoriesRequest): Promise<responses.ListContainerRepositoriesResponse>;
    /**
     * Remove version from container image.
     * @param RemoveContainerVersionRequest
     * @return RemoveContainerVersionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.19.4/artifacts/RemoveContainerVersion.ts.html |here} to see how to use RemoveContainerVersion API.
     */
    removeContainerVersion(removeContainerVersionRequest: requests.RemoveContainerVersionRequest): Promise<responses.RemoveContainerVersionResponse>;
    /**
     * Restore a container image.
     * @param RestoreContainerImageRequest
     * @return RestoreContainerImageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.19.4/artifacts/RestoreContainerImage.ts.html |here} to see how to use RestoreContainerImage API.
     */
    restoreContainerImage(restoreContainerImageRequest: requests.RestoreContainerImageRequest): Promise<responses.RestoreContainerImageResponse>;
    /**
     * Update container configuration.
     * @param UpdateContainerConfigurationRequest
     * @return UpdateContainerConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.19.4/artifacts/UpdateContainerConfiguration.ts.html |here} to see how to use UpdateContainerConfiguration API.
     */
    updateContainerConfiguration(updateContainerConfigurationRequest: requests.UpdateContainerConfigurationRequest): Promise<responses.UpdateContainerConfigurationResponse>;
    /**
     * Modify the properties of a container repository. Avoid entering confidential information.
     * @param UpdateContainerRepositoryRequest
     * @return UpdateContainerRepositoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/1.19.4/artifacts/UpdateContainerRepository.ts.html |here} to see how to use UpdateContainerRepository API.
     */
    updateContainerRepository(updateContainerRepositoryRequest: requests.UpdateContainerRepositoryRequest): Promise<responses.UpdateContainerRepositoryResponse>;
}
